"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs");
var path = require("path");
var Db = /** @class */ (function () {
    function Db(name) {
        this.fname = path.resolve(name + ".json");
        this.parent = {};
        if (!fs.existsSync(this.fname)) {
            fs.writeFileSync(this.fname, "{}");
        }
    }
    Db.prototype.read = function (path) {
        var file = fs.readFileSync(this.fname, "utf8");
        var object = JSON.parse(file);
        if (path !== undefined) {
            return object[path];
        }
        return object;
    };
    Db.prototype.push = function (path, data) {
        this.parent[path] = data;
        var insert = JSON.stringify(this.parent);
        fs.writeFileSync(this.fname, insert);
    };
    Db.prototype.truncate = function () {
        this.parent = {};
        this.update();
    };
    Db.prototype.delete = function (path) {
        delete (this.parent[path]);
        this.update();
    };
    Db.prototype.unlink = function () {
        fs.unlinkSync(this.fname);
    };
    Db.prototype.exists = function () {
        return fs.existsSync(this.fname);
    };
    Db.prototype.update = function () {
        this.insert(this.parent);
    };
    Db.prototype.insert = function (object) {
        var data = JSON.stringify(object);
        fs.writeFileSync(this.fname, data);
    };
    return Db;
}());
exports.default = Db;
